# September 5, 2023 - Version 1.2.1

## Summary

---

**🔗 UX Improvement: Warning added to periodtype non-needed Estimate Data Component**


Please update PrismStudio via

```python
pip install prismstudio --upgrade
```

or

```python
pip install prismstudio==1.2.1
```

## September 5, 2023 -
PrismStudio 1.2.1

---

### UX Improvement

- Warning added to periodtype non-needed Estimate Data Component
